@@ -2,12 +2,12 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2021, by Samuel Williams.
+# Copyright, 2021-2024, by Samuel Williams.
 
-require 'benchmark/ips'
-require 'fiber'
+require "benchmark/ips"
+require "fiber"
 
-require_relative '../lib/event'
+require_relative "../lib/event"
 
 GC.disable
 
