@@ -2,12 +2,12 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2021, by Samuel Williams.
+# Copyright, 2021-2024, by Samuel Williams.
 
-require 'socket'
+require "socket"
 
 port = Integer(ARGV.pop || 9090)
-server = TCPServer.new('localhost', port)
+server = TCPServer.new("localhost", port)
 
 loop do
 	peer = server.accept
