@@ -2,10 +2,12 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2021-2024, by Samuel Williams.
+# Copyright, 2021-2025, by Samuel Williams.
 
 require "socket"
 
+RESPONSE = "HTTP/1.1 204 No Content\r\nConnection: close\r\n\r\n"
+
 port = Integer(ARGV.pop || 9090)
 server = TCPServer.new("localhost", port)
 
@@ -14,7 +16,7 @@ loop do
 	
 	Thread.new do
 		peer.recv(1024)
-		peer.send("HTTP/1.1 204 No Content\r\nConnection: close\r\n\r\n", 0)
+		peer.send(RESPONSE, 0)
 		peer.close
 	end
 end
