@@ -2,10 +2,10 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2021, by Samuel Williams.
+# Copyright, 2021-2024, by Samuel Williams.
 
-require 'fiber'
-require '../lib/event'
+require "fiber"
+require "../lib/event"
 
 th = Thread.new do
 	selector = Event::Selector.new(Fiber.current)
